import os
import sys
import logging
from dotenv import load_dotenv

# Add the project root directory to the Python path
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

from src.managers.telegram_bot import TelegramBot

# Configure logging
logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
    handlers=[logging.StreamHandler(sys.stdout)],
)

logger = logging.getLogger(__name__)


def main():
    # Load environment variables
    load_dotenv()

    try:
        # Initialize and run the bot
        logger.info("Initializing Telegram bot...")
        bot = TelegramBot()
        logger.info("Bot is starting...")
        bot.run()
    except Exception as e:
        logger.error(f"Error starting bot: {str(e)}", exc_info=True)
        sys.exit(1)


if __name__ == "__main__":
    main()
